(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     22299,        537]
NotebookOptionsPosition[     22728,        528]
NotebookOutlinePosition[     23193,        548]
CellTagsIndexPosition[     23150,        545]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Thermal Stress\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2018-02-10",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "A change in temperature can cause a body to change its dimensions. For \
homogeneous and isotropic materials with its expansion or contraction \
linearly related to the temperature increase or decrease, the displacement \
can be calculated using the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", "T"], "=", "\[Alpha]\[CapitalDelta]TL"}], 
   TraditionalForm]],
  FontColor->GrayLevel[0]],
 ", where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "T"], TraditionalForm]],
  FontColor->GrayLevel[0]],
 " is the algebraic change in length, ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]],
  FontColor->GrayLevel[0]],
 " is the linear coefficient of thermal expansion, ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]T", TraditionalForm]],
  FontColor->GrayLevel[0]],
 " is the algebraic change in temperature and ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],
  FontColor->GrayLevel[0]],
 " is the original length. \nIn the present case, a member with original \
length ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "0"], TraditionalForm]],
  FontColor->GrayLevel[0]],
 " is fixed on the left and free on the right, with a distance ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", "0"], TraditionalForm]],
  FontColor->GrayLevel[0]],
 " to the right wall. When temperature is increased, the end on the right \
will expand, but no thermal stress will be produced until its reaches the \
wall. After touching with the wall, and continuously increase the \
temperature, then thermal stress will be produced. Think about how to \
calculate the thermal stress, and click on \
\[OpenCurlyDoubleQuote]Superposition\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]Calculation\[CloseCurlyDoubleQuote] for checking. "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`cal$$ = False, $CellContext`mat$$ = 
    "Steel", $CellContext`sup$$ = False, $CellContext`t$$ = 
    0, $CellContext`tmax$$ = 100, $CellContext`tmin$$ = 0, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`t$$], 0, ""}, 
      Dynamic[$CellContext`tmin$$], 
      Dynamic[$CellContext`tmax$$], 1}, {{
       Hold[$CellContext`mat$$], "Steel", Null}, {
      "Steel" -> "Steel", "Copper" -> "Cop.", "Aluminum" -> "Alum."}}, {{
       Hold[$CellContext`sup$$], False, Null}, {True -> Row[{
          Text["On"], 
          Spacer[10.5]}], False -> "Off"}}, {{
       Hold[$CellContext`cal$$], False, Null}, {True -> Row[{
          Text["On"], 
          Spacer[10.5]}], False -> "Off"}}, {
      Hold[
       Grid[{{
          Row[{
            Text["Temperature Increase \[Delta]t (\[Degree]C)"]}]}, {
          Manipulate`Place[1]}, {
          Row[{
            Text["Materials"]}]}, {
          Manipulate`Place[2]}, {
          Row[{
            Text["Superposition"]}]}, {
          Manipulate`Place[3]}, {}, {
          Grid[{{
             Text[""], 
             Text["Steel"], 
             Text["Cop."], 
             Text["Alum."]}, {
             Text["E (GPa)"], 
             Text["200"], 
             Text["101"], 
             Text["68.9"]}, {
             Grid[{{
                Text["\[Alpha] ("], 
                Superscript["10", "-6"], 
                Text["/\[Degree]C)"]}}, Spacings -> 0], 
             Text["12"], 
             Text["18"], 
             Text["24"]}, {
             Text[
              Row[{
                Subscript["L", "0"], "= 1"}]], SpanFromLeft}, {
             Text[
              Row[{
                Subscript["\[CapitalDelta]", "0"], "=", 
                NumberForm[0.0004999999999999999, 3]}]], SpanFromLeft}}, 
           Frame -> All, Alignment -> Center]}, {}, {
          Row[{
            Text["Show Calculation"]}]}, {
          Manipulate`Place[4]}, {}, {
          Dynamic[
           If[$CellContext`cal$$, $CellContext`temp1 = Grid[{{
                Row[{
                  Text[
                   Subscript["\[Delta]t", "c"]], 
                  Text[" = "], 
                  Text[
                   Subscript["\[CapitalDelta]", "0"]], 
                  Text["/"], 
                  Text["(\[Alpha]"], 
                  Text[
                   Subscript["L", "0"]], 
                  Text[") = "], 
                  Dynamic[
                   NumberForm[
                    N[$CellContext`tpc], {3, 2}]]}]}, {
                Row[{
                  Text["If"], 
                  Text["\[Delta]t<"], 
                  Text[
                   Subscript["\[Delta]t", "c"]], 
                  Text[" \[DoubleLongLeftRightArrow] "], 
                  Text[
                   Subscript["\[CapitalDelta]", "1"]], 
                  Text["<"], 
                  Text[
                   Subscript["\[CapitalDelta]", "0"]]}]}, {
                Text["\[Sigma] = 0"]}, {
                Row[{
                  Text["If"], 
                  Text["\[Delta]t>"], 
                  Text[
                   Subscript["\[Delta]t", "c"]], 
                  Text[" \[DoubleLongLeftRightArrow] "], 
                  Text[
                   Subscript["\[CapitalDelta]", "1"]], 
                  Text[">"], 
                  Text[
                   Subscript["\[CapitalDelta]", "0"]]}]}, {
                Row[{
                  Text["\[Sigma] = E(\[Alpha]"], 
                  Text[
                   Subscript["L", "0"]], 
                  Text["\[Delta]t-"], 
                  Text[
                   Subscript["\[CapitalDelta]", "0"]], 
                  Text[")"]}]}, {
                Text[
                 Row[{"\[Sigma] = ", 
                   NumberForm[
                    Dynamic[
                    N[$CellContext`ths]], 3], " (MPa)"}]]}}, Alignment -> 
              Left], 
            Invisible[$CellContext`temp1]]]}}, Alignment -> Left]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`tmin$$], 0}, 0}, {{
       Hold[$CellContext`tmax$$], 100}, 0}}, Typeset`size$$ = {
    860., {123., 132.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`t$81357$$ = 
    0, $CellContext`mat$81358$$ = False, $CellContext`sup$81359$$ = 
    False, $CellContext`cal$81360$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`cal$$ = False, $CellContext`mat$$ = 
        "Steel", $CellContext`sup$$ = False, $CellContext`t$$ = 
        0, $CellContext`tmax$$ = 100, $CellContext`tmin$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$81357$$, 0], 
        Hold[$CellContext`mat$$, $CellContext`mat$81358$$, False], 
        Hold[$CellContext`sup$$, $CellContext`sup$81359$$, False], 
        Hold[$CellContext`cal$$, $CellContext`cal$81360$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{}, $CellContext`exp = 
         Switch[$CellContext`mat$$, "Steel", 12 10^(-6), "Copper", 18 10^(-6),
            "Aluminum", 24 10^(-6)]; $CellContext`ey = 
         Switch[$CellContext`mat$$, "Steel", 200 10^9, "Copper", 101 10^9, 
           "Aluminum", 68.9 10^9]; $CellContext`l = 1; $CellContext`h = 
         0.2; $CellContext`\[CapitalDelta]h = 
         0.1 $CellContext`h; $CellContext`fac = 1.5; $CellContext`lr = 
         1. $CellContext`l; $CellContext`table = 
         Table[$CellContext`i, {$CellContext`i, ((-$CellContext`h)/
             2) $CellContext`fac, ($CellContext`h/
             2) $CellContext`fac, $CellContext`fac (($CellContext`h/2)/
             4)}]; $CellContext`tablear = 
         Table[$CellContext`i, {$CellContext`i, (-0.5) $CellContext`h, 
            0.5 $CellContext`h, 
            0.2 $CellContext`h}]; $CellContext`\[CapitalDelta]l = \
($CellContext`l $CellContext`exp) $CellContext`t$$; $CellContext`exa = 
         200; $CellContext`\[CapitalDelta]lfic = $CellContext`exa \
$CellContext`\[CapitalDelta]l; $CellContext`endzero = 
         0.9 $CellContext`l; $CellContext`endt = $CellContext`endzero + \
$CellContext`\[CapitalDelta]lfic; $CellContext`tpc = ($CellContext`lr - \
$CellContext`endzero)/(($CellContext`l $CellContext`exp) $CellContext`exa); \
$CellContext`endtcs = 
         If[$CellContext`t$$ < $CellContext`tpc, $CellContext`endzero + \
$CellContext`\[CapitalDelta]lfic, $CellContext`lr]; $CellContext`\
\[CapitalDelta] = 
         If[$CellContext`t$$ > $CellContext`tpc, \
$CellContext`\[CapitalDelta]l - ($CellContext`lr - \
$CellContext`endzero)/$CellContext`exa, 
           0]; $CellContext`ths = $CellContext`ey (($CellContext`\
\[CapitalDelta]/$CellContext`l)/10^6); $CellContext`thsmax = 
         200; $CellContext`imzx = 500; $CellContext`imzy = 
         150; $CellContext`rgxl = (-0.1) $CellContext`l; $CellContext`rgxr = 
         1.5 $CellContext`l; $CellContext`rgyl = (-1.2) $CellContext`h; \
$CellContext`rgyr = 1.2 $CellContext`h; Grid[{{
            Grid[{{
               Graphics[{
                 Thickness[0.003], 
                 
                 Line[{{0, ((-$CellContext`h)/2) $CellContext`fac}, {
                   0, ($CellContext`h/2) $CellContext`fac}}], 
                 Map[Line[{{0, #}, {0, #} + $CellContext`\[CapitalDelta]h {
                    Cos[225 Degree], 
                    Sin[225 Degree]}}]& , $CellContext`table], 
                 Line[{{$CellContext`lr, ((-$CellContext`h)/
                    2) $CellContext`fac}, {$CellContext`lr, ($CellContext`h/
                    2) $CellContext`fac}}], 
                 Map[
                 Line[{{$CellContext`lr, #}, {$CellContext`lr, #} + \
$CellContext`\[CapitalDelta]h {
                    Cos[(-45) Degree], 
                    Sin[(-45) Degree]}}]& , $CellContext`table], 
                 FaceForm[{
                   RGBColor[
                   1, 1 - $CellContext`ths/$CellContext`thsmax, 
                    1 - $CellContext`ths/$CellContext`thsmax]}], 
                 EdgeForm[{Black, 
                   Thickness[0.003]}], 
                 
                 Rectangle[{
                  0, (-$CellContext`h)/
                   2}, {$CellContext`endtcs, $CellContext`h/2}], 
                 Arrowheads[0.02], 
                 
                 Arrow[{{0 + 0.4 $CellContext`l, 0.9 $CellContext`rgyr}, {
                   0, 0.9 $CellContext`rgyr}}], 
                 
                 Arrow[{{$CellContext`endzero - 0.4 $CellContext`l, 
                    0.9 $CellContext`rgyr}, {$CellContext`endzero, 
                    0.9 $CellContext`rgyr}}], 
                 
                 Arrow[{{$CellContext`lr + 0.1 $CellContext`l, 
                    0.9 $CellContext`rgyr}, {$CellContext`lr, 
                    0.9 $CellContext`rgyr}}], Dashed, 
                 
                 Line[{{$CellContext`endzero, $CellContext`rgyl}, \
{$CellContext`endzero, $CellContext`rgyr}}], 
                 
                 Line[{{$CellContext`lr, $CellContext`rgyl}, \
{$CellContext`lr, $CellContext`rgyr}}], 
                 Text[
                  Subscript[
                  "\[CapitalDelta]", 
                   "0"], {(1/2) ($CellContext`endzero + $CellContext`lr), 
                   0.9 $CellContext`rgyr}], 
                 Line[{{0, $CellContext`rgyl}, {0, $CellContext`rgyr}}], 
                 Text[
                  Subscript[
                  "L", "0"], {(1/2) $CellContext`endzero, 
                   0.9 $CellContext`rgyr}]}, 
                PlotRange -> {{$CellContext`rgxl, $CellContext`rgxr}, \
{$CellContext`rgyl, $CellContext`rgyr}}, 
                ImageSize -> {$CellContext`imzx, $CellContext`imzy}], 
               BarLegend[{{
                  RGBColor[1, 1, 1], 
                  RGBColor[1, 0, 0]}, {0, $CellContext`thsmax}}, 
                LegendMarkerSize -> 150]}}, Frame -> False]}, {
            If[$CellContext`sup$$, 
             Grid[{{
                Style[
                 Text["="], Bold, 30]}, {
                Graphics[{
                  Thickness[0.003], 
                  
                  Line[{{0, ((-$CellContext`h)/2) $CellContext`fac}, {
                    0, ($CellContext`h/2) $CellContext`fac}}], 
                  Map[Line[{{0, #}, {0, #} + $CellContext`\[CapitalDelta]h {
                    Cos[225 Degree], 
                    Sin[225 Degree]}}]& , $CellContext`table], 
                  Map[
                  Line[{{0, #}, {$CellContext`endt, #}}]& , \
{(-$CellContext`h)/2, $CellContext`h/2}], 
                  
                  Line[{{$CellContext`endt, $CellContext`h/
                    2}, {$CellContext`endt, (-$CellContext`h)/2}}], 
                  If[$CellContext`t$$ > 0, {
                    Arrowheads[0.02], 
                    
                    Arrow[{{$CellContext`endzero - 0.1 $CellContext`l, 
                    0.9 $CellContext`rgyr}, {$CellContext`endzero, 
                    0.9 $CellContext`rgyr}}], 
                    
                    Arrow[{{$CellContext`endt + 0.1 $CellContext`l, 
                    0.9 $CellContext`rgyr}, {$CellContext`endt, 
                    0.9 $CellContext`rgyr}}], Dashed, 
                    
                    Line[{{$CellContext`endzero, $CellContext`rgyl}, \
{$CellContext`endzero, $CellContext`rgyr}}], 
                    
                    Line[{{$CellContext`endt, $CellContext`rgyl}, \
{$CellContext`endt, $CellContext`rgyr}}], 
                    Text[
                    Subscript[
                    "\[CapitalDelta]", "1"], {$CellContext`endt + 
                    0.07 $CellContext`l, 0.8 $CellContext`rgyr}]}]}, 
                 PlotRange -> {{$CellContext`rgxl, $CellContext`rgxr}, \
{$CellContext`rgyl, $CellContext`rgyr}}, 
                 ImageSize -> {$CellContext`imzx, $CellContext`imzy}]}, {
                Style[
                 Text["+"], Bold, 30]}, {
                Graphics[{
                  Thickness[0.003], 
                  Line[{{0, ((-$CellContext`h)/2) $CellContext`fac}, {
                    0, ($CellContext`h/2) $CellContext`fac}}], 
                  Map[Line[{{0, #}, {0, #} + $CellContext`\[CapitalDelta]h {
                    Cos[225 Degree], 
                    Sin[225 Degree]}}]& , $CellContext`table], 
                  Map[
                  Line[{{0, #}, {$CellContext`endtcs, #}}]& , \
{(-$CellContext`h)/2, $CellContext`h/2}], 
                  
                  Line[{{$CellContext`endtcs, $CellContext`h/
                    2}, {$CellContext`endtcs, (-$CellContext`h)/2}}], 
                  If[$CellContext`t$$ > $CellContext`tpc, {Red, 
                    Arrowheads[0.02], 
                    Map[
                    Arrow[{{$CellContext`endt, #}, {$CellContext`lr, #}}]& , \
$CellContext`tablear], Black, 
                    Arrowheads[0.02], 
                    
                    Arrow[{{$CellContext`lr - 0.1 $CellContext`l, 
                    0.9 $CellContext`rgyr}, {$CellContext`lr, 
                    0.9 $CellContext`rgyr}}], 
                    
                    Arrow[{{$CellContext`endt + 0.1 $CellContext`l, 
                    0.9 $CellContext`rgyr}, {$CellContext`endt, 
                    0.9 $CellContext`rgyr}}], Dashed, 
                    
                    Line[{{$CellContext`lr, $CellContext`rgyl}, \
{$CellContext`lr, $CellContext`rgyr}}], 
                    
                    Line[{{$CellContext`endt, $CellContext`rgyl}, \
{$CellContext`endt, $CellContext`rgyr}}], 
                    Text[
                    "\[CapitalDelta]", {$CellContext`endt + 
                    0.07 $CellContext`l, 0.8 $CellContext`rgyr}]}]}, 
                 PlotRange -> {{$CellContext`rgxl, $CellContext`rgxr}, \
{$CellContext`rgyl, $CellContext`rgyr}}, 
                 ImageSize -> {$CellContext`imzx, $CellContext`imzy}]}}, 
              Frame -> False]], SpanFromLeft}}, Frame -> False, Alignment -> 
          Left]], "Specifications" :> {{{$CellContext`t$$, 0, ""}, 
         Dynamic[$CellContext`tmin$$], 
         Dynamic[$CellContext`tmax$$], 1, Appearance -> "Labeled", ImageSize -> 
         Small, ControlPlacement -> 
         1}, {{$CellContext`mat$$, "Steel", Null}, {
         "Steel" -> "Steel", "Copper" -> "Cop.", "Aluminum" -> "Alum."}, 
         ControlType -> RadioButton, ControlPlacement -> 
         2}, {{$CellContext`sup$$, False, Null}, {True -> Row[{
             Text["On"], 
             Spacer[10.5]}], False -> "Off"}, ControlType -> RadioButton, 
         ControlPlacement -> 3}, {{$CellContext`cal$$, False, Null}, {
         True -> Row[{
             Text["On"], 
             Spacer[10.5]}], False -> "Off"}, ControlType -> RadioButton, 
         ControlPlacement -> 4}, 
        Grid[{{
           Row[{
             Text["Temperature Increase \[Delta]t (\[Degree]C)"]}]}, {
           Manipulate`Place[1]}, {
           Row[{
             Text["Materials"]}]}, {
           Manipulate`Place[2]}, {
           Row[{
             Text["Superposition"]}]}, {
           Manipulate`Place[3]}, {}, {
           Grid[{{
              Text[""], 
              Text["Steel"], 
              Text["Cop."], 
              Text["Alum."]}, {
              Text["E (GPa)"], 
              Text["200"], 
              Text["101"], 
              Text["68.9"]}, {
              Grid[{{
                 Text["\[Alpha] ("], 
                 Superscript["10", "-6"], 
                 Text["/\[Degree]C)"]}}, Spacings -> 0], 
              Text["12"], 
              Text["18"], 
              Text["24"]}, {
              Text[
               Row[{
                 Subscript["L", "0"], "= 1"}]], SpanFromLeft}, {
              Text[
               Row[{
                 Subscript["\[CapitalDelta]", "0"], "=", 
                 NumberForm[0.0004999999999999999, 3]}]], SpanFromLeft}}, 
            Frame -> All, Alignment -> Center]}, {}, {
           Row[{
             Text["Show Calculation"]}]}, {
           Manipulate`Place[4]}, {}, {
           Dynamic[
            If[$CellContext`cal$$, $CellContext`temp1 = Grid[{{
                 Row[{
                   Text[
                    Subscript["\[Delta]t", "c"]], 
                   Text[" = "], 
                   Text[
                    Subscript["\[CapitalDelta]", "0"]], 
                   Text["/"], 
                   Text["(\[Alpha]"], 
                   Text[
                    Subscript["L", "0"]], 
                   Text[") = "], 
                   Dynamic[
                    NumberForm[
                    N[$CellContext`tpc], {3, 2}]]}]}, {
                 Row[{
                   Text["If"], 
                   Text["\[Delta]t<"], 
                   Text[
                    Subscript["\[Delta]t", "c"]], 
                   Text[" \[DoubleLongLeftRightArrow] "], 
                   Text[
                    Subscript["\[CapitalDelta]", "1"]], 
                   Text["<"], 
                   Text[
                    Subscript["\[CapitalDelta]", "0"]]}]}, {
                 Text["\[Sigma] = 0"]}, {
                 Row[{
                   Text["If"], 
                   Text["\[Delta]t>"], 
                   Text[
                    Subscript["\[Delta]t", "c"]], 
                   Text[" \[DoubleLongLeftRightArrow] "], 
                   Text[
                    Subscript["\[CapitalDelta]", "1"]], 
                   Text[">"], 
                   Text[
                    Subscript["\[CapitalDelta]", "0"]]}]}, {
                 Row[{
                   Text["\[Sigma] = E(\[Alpha]"], 
                   Text[
                    Subscript["L", "0"]], 
                   Text["\[Delta]t-"], 
                   Text[
                    Subscript["\[CapitalDelta]", "0"]], 
                   Text[")"]}]}, {
                 Text[
                  Row[{"\[Sigma] = ", 
                    NumberForm[
                    Dynamic[
                    N[$CellContext`ths]], 3], " (MPa)"}]]}}, Alignment -> 
               Left], 
             Invisible[$CellContext`temp1]]]}}, Alignment -> 
         Left], {{$CellContext`tmin$$, 0}, 0, ControlType -> 
         None}, {{$CellContext`tmax$$, 100}, 0, ControlType -> None}}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{1196., {260., 269.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 200, 7, 230, "Title"],
Cell[1689, 44, 1811, 46, 188, "Text"],
Cell[3503, 92, 19209, 433, 553, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature zx07uIhsKyv7fA1lQC0GDsNI *)
